@@ -11,7 +11,7 @@ class FileOrganizer:
     @classmethod
     def unpack(cls, src_dir, dest_dir, *, pool=None, index=None, descent=None):
         tasks = []
-        cls._unpack(src_dir, dest_dir, '', tasks, index, descent)
+        cls._unpack(src_dir, os.path.abspath(dest_dir), '', tasks, index, descent)
         helper.run_in_pool(cls.unpack_code_file, tasks, pool=pool)
 
     @classmethod
@@ -35,7 +35,7 @@ class FileOrganizer:
         dest_entry_path, dest_file_name = CodeOrganizer.get_dest_path(dest_dir, dest_path, dest_file_name, index)
         if dest_entry_path:
             os.makedirs(os.path.join(dest_dir, dest_entry_path), exist_ok=True)
-        dest_full_path = os.path.abspath(os.path.join(dest_dir, dest_entry_path))
+        dest_full_path = os.path.join(dest_dir, dest_entry_path)
 
         src_full_path = os.path.join(src_path, src_file_name)
 
@@ -72,7 +72,11 @@ class FileOrganizer:
                 if descent_file_name:
                     helper.txt_write(_file['data'], descent_full_dest_path, descent_file_name)
         except Exception as err:
-            raise ExtException(parent=err, detail=os.path.join(src_dir, path, file_name))
+            raise ExtException(
+                parent=err,
+                dump={"filename": os.path.join(src_dir, path, file_name)},
+                action='unpack_code_file'
+            )
 
     @classmethod
     def equal_binary_file(cls, src_path, src_file_name, src_data, near_descent_path, near_descent_file_name):
@@ -100,6 +104,7 @@ class FileOrganizer:
     def pack(cls, src_dir, dest_dir, *, pool=None, index=None, descent=None):
         helper.clear_dir(dest_dir)
         tasks = []
+        src_dir = os.path.abspath(src_dir)
         cls.pack_index(src_dir, dest_dir, tasks, index, descent)
         cls._pack(src_dir, dest_dir, '', tasks, index, descent)
         helper.run_in_pool(CodeOrganizer.pack, tasks, pool=pool)
