@@ -57,7 +57,7 @@ def extract(in_filename: str, out_dir_name: str, *, temp_dir=None, index=None, v
     begin4 = datetime.now()
     print(f" - {begin4 - begin3}\n{helper.str_time(begin0)} Организуем    ", end='')
     if descent:
-        FileOrganizerCE.unpack(stage3_dir, out_dir_name, pool=pool, index=index, descent=version)
+        FileOrganizerCE.unpack(stage3_dir, out_dir_name, pool=pool, index=index, descent=descent)
     else:
         FileOrganizer.unpack(stage3_dir, out_dir_name, pool=pool, index=index)
 
@@ -162,12 +162,12 @@ def main():
     args = parser.parse_args()
 
     if args.E is not None:
-        extract(args.E[0], args.E[1],
-                index=args.index, temp_dir=args.temp, version=args.version, descent=args.descent)
+        extract(os.path.abspath(args.E[0]), os.path.abspath(args.E[1]),
+                index=args.index, temp_dir=args.temp, version=args.version, descent=int(args.descent))
 
     if args.B is not None:
-        build(args.B[0], args.B[1],
-              index=args.index, temp_dir=args.temp, version=args.version, descent=args.descent)
+        build(os.path.abspath(args.B[0]), os.path.abspath(args.B[1]),
+              index=args.index, temp_dir=args.temp, version=args.version, descent=int(args.descent))
 
     if args.I is not None:
         update_index(args.I[0], args.index, args.core)
